---
title: <span class="badge object-type-scalar"></span> SouthAfricanRand
---
# <span class="badge object-type-scalar"></span> SouthAfricanRand

Currency: South African Rand (R)

## Definition

```python
# Currency: South African Rand (R)
SouthAfricanRand: typing.Literal["currencyZAR"] = "currencyZAR"
```
